==> jc-1.4.0.tar.gz: gnu/xml/xpath/Pattern.h <==
// public abstract class gnu.xml.xpath.Pattern

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_xpath_Pattern_H_
#define _JC_gnu_xml_xpath_Pattern_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Pattern$sub_refs	_jc_gnu_xml_xpath_Pattern$sub_refs;
typedef struct _jc_gnu_xml_xpath_Pattern$sub_nonrefs	_jc_gnu_xml_xpath_Pattern$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Pattern$refs	_jc_gnu_xml_xpath_Pattern$refs;
typedef struct _jc_gnu_xml_xpath_Pattern$nonrefs	_jc_gnu_xml_xpath_Pattern$nonrefs;
typedef struct _jc_gnu_xml_xpath_Pattern$object	_jc_gnu_xml_xpath_Pattern$object;

typedef const struct _jc_gnu_xml_xpath_Pattern$vmethods	_jc_gnu_xml_xpath_Pattern$vmethods;
typedef const struct _jc_gnu_xml_xpath_Pattern$vtable	_jc_gnu_xml_xpath_Pattern$vtable;
typedef const struct _jc_gnu_xml_xpath_Pattern$vtype	_jc_gnu_xml_xpath_Pattern$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Pattern$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_Pattern$object *);

// Virtual methods
extern jboolean _jc_gnu_xml_xpath_Pattern$method$matches$bd70941b9693d4d7(_jc_env *, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Pattern$method_info$matches$bd70941b9693d4d7;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Pattern$vmethods {
	jboolean	(*matches$bd70941b9693d4d7)(_jc_env *, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_xml_xpath_Pattern$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_Pattern$vmethods	gnu_xml_xpath_Pattern;
};

// Vtype
struct _jc_gnu_xml_xpath_Pattern$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Pattern$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Pattern$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Pattern$refs {
    _jc_gnu_xml_xpath_Pattern$sub_refs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Pattern$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Pattern$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_Pattern$sub_nonrefs	gnu_xml_xpath_Pattern;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Pattern$object {
	_jc_gnu_xml_xpath_Pattern$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Pattern$vtype	*vtype;
	_jc_gnu_xml_xpath_Pattern$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Pattern$vtype _jc_gnu_xml_xpath_Pattern$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Pattern, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Pattern$class_object;

#endif	/* _JC_gnu_xml_xpath_Pattern_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/Pattern.h <==
// public abstract class gnu.xml.xpath.Pattern

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_xpath_Pattern_H_
#define _JC_gnu_xml_xpath_Pattern_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Pattern$sub_refs	_jc_gnu_xml_xpath_Pattern$sub_refs;
typedef struct _jc_gnu_xml_xpath_Pattern$sub_nonrefs	_jc_gnu_xml_xpath_Pattern$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Pattern$refs	_jc_gnu_xml_xpath_Pattern$refs;
typedef struct _jc_gnu_xml_xpath_Pattern$nonrefs	_jc_gnu_xml_xpath_Pattern$nonrefs;
typedef struct _jc_gnu_xml_xpath_Pattern$object	_jc_gnu_xml_xpath_Pattern$object;

typedef const struct _jc_gnu_xml_xpath_Pattern$vmethods	_jc_gnu_xml_xpath_Pattern$vmethods;
typedef const struct _jc_gnu_xml_xpath_Pattern$vtable	_jc_gnu_xml_xpath_Pattern$vtable;
typedef const struct _jc_gnu_xml_xpath_Pattern$vtype	_jc_gnu_xml_xpath_Pattern$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Pattern$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_Pattern$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_xml_xpath_Pattern$method$matches$bd70941b9693d4d7(_jc_env *, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Pattern$method_info$matches$bd70941b9693d4d7;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Pattern$vmethods {
	jboolean	(*matches$bd70941b9693d4d7)(_jc_env *, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_Pattern$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_Pattern$vmethods	gnu_xml_xpath_Pattern;
};

// Vtype
struct _jc_gnu_xml_xpath_Pattern$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Pattern$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Pattern$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Pattern$refs {
    _jc_gnu_xml_xpath_Pattern$sub_refs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Pattern$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Pattern$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_Pattern$sub_nonrefs	gnu_xml_xpath_Pattern;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Pattern$object {
	_jc_gnu_xml_xpath_Pattern$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Pattern$vtype	*vtype;
	_jc_gnu_xml_xpath_Pattern$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Pattern$vtype _jc_gnu_xml_xpath_Pattern$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Pattern, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Pattern$class_object;

#endif	/* _JC_gnu_xml_xpath_Pattern_H_ */
